@@ -6,7 +6,6 @@ import os
 import sys
 import select
 import signal
-import termios
 import xml.dom.minidom
 
 import game
@@ -36,12 +35,12 @@ class Profile:
     """
     name       = ''
     protocol   = ''
-    executable = ''
     path       = ''
     arguments  = None
     profiles   = None
     
     def __init__(self):
+        self.executables = []
         self.arguments = []
         self.profiles = {}
 
@@ -54,10 +53,11 @@ class Profile:
             path = []
 
         for directory in path:
-            b = directory + os.sep + self.executable
-            if os.path.isfile(b):
-                self.path = b
-                return
+            for executable in self.executables:
+                b = directory + os.sep + executable
+                if os.path.isfile(b):
+                    self.path = b
+                    return
         self.path = None
         
 def _getXMLText(node):
@@ -132,12 +132,14 @@ def loadProfiles():
             n = p.getElementsByTagName('name')
             assert(len(n) > 0)
             name = _getXMLText(n[0])
-            
+
+            executables = []
             n = p.getElementsByTagName('binary')
             assert(len(n) > 0)
-            executable = _getXMLText(n[0])
-            
-            arguments = [executable]
+            for x in n:
+                executables.append(_getXMLText(x))
+
+            arguments = []
             for x in p.getElementsByTagName('argument'):
                 arguments.append(_getXMLText(x))
 
@@ -148,11 +150,11 @@ def loadProfiles():
                     levels[level.name] = level
 
             profile = Profile()
-            profile.name       = name
-            profile.protocol   = protocol
-            profile.executable = executable
-            profile.arguments  = arguments
-            profile.levels     = levels
+            profile.name        = name
+            profile.protocol    = protocol
+            profile.executables = executables
+            profile.arguments   = arguments
+            profile.levels      = levels
             profiles.append(profile)
     
     return profiles
@@ -175,8 +177,12 @@ class CECPConnection(cecp.Connection):
 
     def onMove(self, move):
         """Called by cecp.Connection"""
-        self.player.moving = True
-        self.player.move(move)
+        if self.player.isReadyToMove():
+            self.player.moving = True
+            self.player.move(move)
+        else:
+            assert(self.player.suppliedMove is None)
+            self.player.suppliedMove = move
         
     def logText(self, text, style):
         """Called by cecp.Connection"""
@@ -214,11 +220,14 @@ class Player(game.ChessPlayer):
     __level      = None
         
     # File object to engine stdin/out/err
-    __fd         = None
+    __fromEngineFd = None
+    __toEngineFd   = None
     
     __connection = None
     
-    moving = False
+    moving       = False
+    
+    suppliedMove = None
     
     def __init__(self, name, profile, level = 'normal'):
         """Constructor for an AI player.
@@ -232,20 +241,102 @@ class Player(game.ChessPlayer):
 
         game.ChessPlayer.__init__(self, name)
         
-        (self.__pid, self.__fd) = os.forkpty()
-        if self.__pid == 0:
-            os.nice(10)
+        # Pipe to communicate to engine with
+        toManagerPipe = os.pipe()
+        fromManagerPipe = os.pipe()
+        
+        # Store the file descripter for reading/writing
+        self.__toEngineFd = toManagerPipe[1]
+        self.__fromEngineFd = fromManagerPipe[0]
+        
+        # Catch if the child dies
+        def cDied(sig, stackFrame):
             try:
-                os.execv(profile.path, profile.arguments)
+                os.waitpid(-1, os.WNOHANG)
             except OSError:
                 pass
+        signal.signal(signal.SIGCHLD, cDied)
+
+        # Fork off a child process to manage the engine
+        self.__pid = os.fork()
+        if self.__pid == 0:
+            # ..
+            os.close(toManagerPipe[1])
+            os.close(fromManagerPipe[0])
+            
+            # Make pipes to the engine
+            stdinPipe = os.pipe()
+            stdoutPipe = os.pipe()
+            stderrPipe = os.pipe()
+            
+            # Fork off the engine
+            engineFd = os.fork()
+            if engineFd == 0:
+                # Make the engine low priority for CPU usage
+                os.nice(19)
+                
+                # Change directory so any log files are not in the users home directory
+                try:
+                    os.mkdir(LOG_DIR)
+                except OSError:
+                    pass
+                try:
+                    os.chdir(LOG_DIR)
+                except OSError:
+                    pass
+                
+                # Connect stdin, stdout and stderr to the manager process
+                os.dup2(stdinPipe[0], sys.stdin.fileno())
+                os.dup2(stdoutPipe[1], sys.stdout.fileno())
+                os.dup2(stderrPipe[1], sys.stderr.fileno())
+                
+                # Execute the engine
+                try:
+                    os.execv(profile.path, [profile.path] + profile.arguments)
+                except OSError:
+                    pass
+                os._exit(0)
+                
+            # Catch if the child dies
+            def childDied(sig, stackFrame):
+                try:
+                    os.waitpid(-1, os.WNOHANG)
+                except OSError:
+                    return
+                
+                # Close connection to the application
+                os.close(fromManagerPipe[1])
+                    
+                os._exit(0)
+            signal.signal(signal.SIGCHLD, childDied)
+
+            # Forward data between the application and the engine and wait for closed pipes
+            inputPipes = [toManagerPipe[0], stdoutPipe[0], stderrPipe[0]]
+            pipes = [toManagerPipe[0], toManagerPipe[1], stdinPipe[0], stdinPipe[1], stdoutPipe[0], stdoutPipe[1], stderrPipe[0], stderrPipe[1]]
+            while True:                
+                # Wait for data
+                (rfds, _, xfds) = select.select(inputPipes, [], pipes, None)
+                
+                for fd in rfds:
+                    data = os.read(fd, 65535)
+                    
+                    # One of the connections has closed - kill the engine and quit
+                    if len(data) == 0:
+                        os.kill(self.__pid, signal.SIGQUIT)
+                        os._exit(0)
+                    
+                    # Send data from the application to the engines stdin
+                    if fd == toManagerPipe[0]:
+                        os.write(stdinPipe[1], data)
+                    # Send engine output to the application
+                    else:
+                        os.write(fromManagerPipe[1], data)
+
             os._exit(0)
             
-        # Stop our commands being echod back
-        (iflag, oflag, cflag, lflag, ispeed, ospeed, cc) = termios.tcgetattr(self.__fd)
-        lflag &= ~termios.ECHO
-        termios.tcsetattr(self.__fd, termios.TCSANOW, [iflag, oflag, cflag, lflag, ispeed, ospeed, cc])
-        
+        os.close(toManagerPipe[0])
+        os.close(fromManagerPipe[1])
+
         if profile.protocol == CECP:
             self.connection = CECPConnection(self)
         elif profile.protocol == UCI:
@@ -280,54 +371,58 @@ class Player(game.ChessPlayer):
     
     def fileno(self):
         """Returns the file descriptor for communicating with the engine (integer)"""
-        return self.__fd
+        return self.__fromEngineFd
 
     def read(self):
         """Read an process data from the engine.
         
         This is non-blocking.
-        """
+        """       
         while True:
+            # Connection was closed
+            if self.__fromEngineFd == None:
+                return False
+
             # Check if data is available
-            (rlist, _, _) = select.select([self.__fd], [], [], 0)
+            (rlist, _, _) = select.select([self.__fromEngineFd], [], [], 0)
             if len(rlist) == 0:
-                return
-            
+                return True
+
             # Read a chunk and process
             try:
-                data = os.read(self.__fd, 256)
+                data = os.read(self.__fromEngineFd, 256)
             except OSError, e:
                 print 'Error reading from chess engine: ' + str(e)
-                return
-            if data == '':
-                return
+                self.die()
+                return False
+            if len(data) == 0:
+                print 'Engine has died'
+                self.die()
+                return False
             self.connection.registerIncomingData(data)
 
     def sendToEngine(self, data):
         """
         """
+        if self.__toEngineFd == None:
+            return
+        
         try:
-            os.write(self.__fd, data)
+            os.write(self.__toEngineFd, data)
         except OSError, e:
             print 'Failed to write to engine: ' + str(e)
 
     def quit(self):
         """Disconnect the AI"""
-        # Wait for the pipe to close
-        # There must be a better way of doing this!
-        count = 0
-        while True:
-            select.select([], [], [], 0.1)
-            try:
-                os.write(self.__fd, '\nquit\n') # FIXME: CECP specific
-            except OSError:
-                return
-            count += 1
-            if count > 5:
-                break
+        fd = self.__toEngineFd
+        self.__toEngineFd = None
+        self.__fromEngineFd = None
         
-        print 'Killing AI'
-        os.kill(self.__pid, signal.SIGKILL)
+        # Send quit
+        try:
+            os.write(fd, '\nquit\n') # FIXME: CECP specific
+        except:
+            return
 
     # Extended methods
     
@@ -336,11 +431,25 @@ class Player(game.ChessPlayer):
         isSelf = player is self and self.moving
         self.moving = False
         self.connection.reportMove(move.canMove, isSelf)
-    
+
     def readyToMove(self):
         """Called by game.ChessPlayer"""
-        self.connection.requestMove()
+        game = self.getGame()
+        whiteTime = game.getWhite().getRemainingTime()
+        blackTime = game.getBlack().getRemainingTime()
+        if game.getWhite() is self:
+            ownTime = whiteTime
+        else:
+            ownTime = blackTime
         
-    def onGameEnded(self, winningPlayer = None):
+        if self.suppliedMove is None:
+            self.connection.requestMove(whiteTime, blackTime, ownTime)
+        else:
+            self.moving = True
+            move = self.suppliedMove
+            self.suppliedMove = None
+            self.move(move)
+        
+    def onGameEnded(self, game):
         """Called by game.ChessPlayer"""
         self.quit()
