@@ -11,7 +11,7 @@ __all__ = ['GtkUI']
 import os
 import sys
 import time
-import gettext
+from gettext import gettext as _
 
 try:
     import pygtk
@@ -99,7 +99,9 @@ class GtkGameNotebook(gtk.Notebook):
     def addView(self, title, feedback):
         """
         """
-        view = chessview.GtkView(self.ui, title, feedback, moveFormat = self.ui.moveFormat)
+        moveFormat = glchess.config.get('move_format')
+        showComments = glchess.config.get('show_comments')
+        view = chessview.GtkView(self.ui, title, feedback, moveFormat = moveFormat, showComments = showComments)
         self.views.append(view)
         self.viewsByWidget[view.widget] = view
         page = self.append_page(view.widget)
@@ -146,7 +148,7 @@ class GtkGameNotebook(gtk.Notebook):
             self.defaultView.widget.show()
         else:
             self.defaultView.widget.hide()
-        
+
 class AIWindow:
     """
     """
@@ -359,10 +361,14 @@ class GtkUI(glchess.ui.UI):
 
     __attentionCounter = 0
 
-    moveFormat         = 'human'
-    
     whiteTimeString    = '∞'
     blackTimeString    = '∞'
+    
+    # The window width and height when unmaximised and not fullscreen
+    width              = None
+    height             = None
+    isFullscreen       = False
+    isMaximised        = False
 
     def __init__(self, feedback):
         """Constructor for a GTK+ glChess GUI"""
@@ -415,13 +421,13 @@ class GtkUI(glchess.ui.UI):
         except gobject.GError:
             icon = None
         iter = self.__playerModel.append()
-        self.__playerModel.set(iter, 0, '', 1, icon, 2, gettext.gettext('Human'))
+        self.__playerModel.set(iter, 0, '', 1, icon, 2, _('Human'))
         #try:
         #    icon = iconTheme.load_icon(gtk.STOCK_NETWORK, 24, gtk.ICON_LOOKUP_USE_BUILTIN)
         #except gobject.GError:
         #    icon = None
         #iter = self.__playerModel.append()
-        #self.__playerModel.set(iter, 0, None, 1, icon, 2, gettext.gettext('Network'))
+        #self.__playerModel.set(iter, 0, None, 1, icon, 2, _('Network'))
         
         self.__aiWindow = AIWindow(self._gui.get_widget('ai_notebook'))
 
@@ -447,7 +453,7 @@ class GtkUI(glchess.ui.UI):
         self.saveDialog = dialogs.SaveDialog(self)
         
         # Watch for config changes
-        for key in ['show_toolbar', 'show_history', 'fullscreen', 'show_3d', 'show_move_hints', 'width', 'height', 'move_format', 'promotion_type', 'board_view']:
+        for key in ['show_toolbar', 'show_history', 'fullscreen', 'show_3d', 'show_comments', 'show_numbering', 'show_move_hints', 'width', 'height', 'move_format', 'promotion_type', 'board_view']:
             glchess.config.watch(key, self.__applyConfig)
 
     # Public methods
@@ -528,7 +534,7 @@ class GtkUI(glchess.ui.UI):
         This method will not return.
         """        
         # Load configuration
-        for name in ['show_toolbar', 'show_history', 'show_3d', 'show_move_hints', 'move_format', 'promotion_type', 'board_view']:
+        for name in ['show_toolbar', 'show_history', 'show_3d', 'show_comments', 'show_numbering', 'show_move_hints', 'move_format', 'promotion_type', 'board_view', 'maximised']:
             try:
                 value = glchess.config.get(name)
             except glchess.config.Error:
@@ -580,6 +586,14 @@ class GtkUI(glchess.ui.UI):
         # Update the open dialogs
         for dialog in self.__joinGameDialogs:
             dialog.removeNetworkGame(game)
+        
+    def close(self):
+        """Extends glchess.ui.UI"""
+        # Save the window size
+        if self.width is not None:
+            glchess.config.set('width', self.width)
+        if self.height is not None:
+            glchess.config.set('height', self.height)
 
     # Protected methods
     
@@ -659,17 +673,21 @@ class GtkUI(glchess.ui.UI):
                 menu.set_active(False)
                 box.hide()
                 
+        # Maximised mode
+        elif name == 'maximised':
+            window = self._gui.get_widget('glchess_app')
+            if value is True:
+                window.maximize()
+            else:
+                window.unmaximize()
+
         # Fullscreen mode
         elif name == 'fullscreen':
             window = self._gui.get_widget('glchess_app')
             if value is True:
                 window.fullscreen()
-                self._gui.get_widget('menu_fullscreen').hide()
-                self._gui.get_widget('menu_leave_fullscreen').show()
             else:
                 window.unfullscreen()
-                self._gui.get_widget('menu_leave_fullscreen').hide()
-                self._gui.get_widget('menu_fullscreen').show()
 
         # Enable/disable OpenGL rendering
         elif name == 'show_3d':            
@@ -684,15 +702,27 @@ class GtkUI(glchess.ui.UI):
             for view in self.notebook.views:
                 view.viewWidget.setRenderGL(self.__renderGL)
                 
+        elif name == 'show_comments':
+            menuItem = self.__getWidget('menu_view_comment')
+            menuItem.set_active(value)
+            for view in self.notebook.views:
+                view.setShowComments(value)
+
         elif name == 'show_move_hints':
             menuItem = self.__getWidget('menu_view_move_hints')
             menuItem.set_active(value)
             for view in self.notebook.views:
                 view.feedback.showMoveHints(value)
-        
+
+        elif name == 'show_numbering':
+            menuItem = self.__getWidget('menu_view_numbering')
+            menuItem.set_active(value)
+            for view in self.notebook.views:
+                view.feedback.showBoardNumbering(value)
+            self.notebook.defaultView.feedback.showBoardNumbering(value)
+
         elif name == 'move_format':
             self._gui.get_widget('menu_movef_%s' % value).set_active(True)
-            self.moveFormat = value
             for view in self.notebook.views:
                 view.setMoveFormat(value)
                 
@@ -800,6 +830,22 @@ class GtkUI(glchess.ui.UI):
             value = False
         glchess.config.set('show_3d', value)
 
+    def _on_menu_view_comment_clicked(self, widget):
+        """Gtk+ callback"""
+        if widget.get_active():
+            value = True
+        else:
+            value = False
+        glchess.config.set('show_comments', value)
+
+    def _on_menu_view_numbering_clicked(self, widget):
+        """Gtk+ callback"""
+        if widget.get_active():
+            value = True
+        else:
+            value = False
+        glchess.config.set('show_numbering', value)       
+
     def _on_toggle_move_hints_clicked(self, widget):
         """Gtk+ callback"""
         if widget.get_active():
@@ -908,7 +954,7 @@ class GtkUI(glchess.ui.UI):
         """Gtk+ callback"""
         # Set the window title to the name of the game
         view = self.notebook.getView()
-        title = gettext.gettext('Chess')
+        title = _('Chess')
         if view is not None:
             title += " - %s" % view.title
         self._gui.get_widget('glchess_app').set_title(title)
@@ -983,7 +1029,7 @@ class GtkUI(glchess.ui.UI):
             gnome.help_display('glchess')
         except gobject.GError, e:
             # TODO: This should be a pop-up dialog
-            print gettext.gettext('Unable to display help: %s') % str(e)
+            print _('Unable to display help: %s') % str(e)
 
     def _on_view_fullscreen_clicked(self, widget):
         """Gtk+ callback"""
@@ -1019,13 +1065,10 @@ class GtkUI(glchess.ui.UI):
         dialog.set_comments(DESCRIPTION)
         dialog.set_authors(AUTHORS)
         dialog.set_artists(ARTISTS)
-        string = ''
-        for t in TRANSLATORS:
-            string += t + '\n'
-        dialog.set_translator_credits(string[:-1])
+        dialog.set_translator_credits(_("translator-credits"))
         dialog.set_website(WEBSITE)
         dialog.set_website_label(WEBSITE_LABEL)
-        dialog.set_logo_icon_name('glchess')
+        dialog.set_logo_icon_name('gnome-glchess')
         dialog.connect('response', self._on_glchess_about_dialog_close)
         dialog.show()
         
@@ -1063,33 +1106,48 @@ class GtkUI(glchess.ui.UI):
     
     def _on_resize(self, widget, event):
         """Gtk+ callback"""
-        glchess.config.set('width', event.width)
-        glchess.config.set('height', event.height)
+        if self.isMaximised or self.isFullscreen:
+            return
+        self.width = event.width
+        self.height = event.height
+
+    def _on_window_state_changed(self, widget, event):
+        """Gtk+ callback"""
+        if event.changed_mask & gtk.gdk.WINDOW_STATE_MAXIMIZED:
+            self.isMaximised = event.new_window_state & gtk.gdk.WINDOW_STATE_MAXIMIZED != 0
+            glchess.config.set('maximised', self.isMaximised)
+            
+        if event.changed_mask & gtk.gdk.WINDOW_STATE_FULLSCREEN:
+            self.isFullscreen = event.new_window_state & gtk.gdk.WINDOW_STATE_FULLSCREEN != 0
+            if self.isFullscreen:
+                self._gui.get_widget('menu_fullscreen').hide()
+                self._gui.get_widget('menu_leave_fullscreen').show()
+            else:
+                self._gui.get_widget('menu_leave_fullscreen').hide()
+                self._gui.get_widget('menu_fullscreen').show()
 
     def _on_close_window(self, widget, event):
         """Gtk+ callback"""
         self._quit()
+        return True
         
     def _on_menu_quit(self, widget):
         """Gtk+ callback"""
         self._quit()
         
-    def _quit(self):
+    def _quit(self):        
         # Check if any views need saving
         viewsToSave = []
         for view in self.notebook.views:
             if view.feedback.needsSaving():
                 viewsToSave.append(view)
-             
+
         if len(viewsToSave) == 0:
             self.feedback.onQuit()
         else:
             self.saveDialog.setViews(viewsToSave)
             self.saveDialog.setVisible(True)
 
-        # Don't close the window, we will do it ourself
-        return True
-
 if __name__ == '__main__':
     ui = GtkUI()
     ui.run()
