@@ -29,6 +29,7 @@
 #include <games-gridframe.h>
 #include <games-stock.h>
 #include <games-scores.h>
+#include <games-sound.h>
 
 #include "main.h"
 #include "properties.h"
@@ -160,13 +161,15 @@ network_gui_update (void)
 #endif
 }
 
-static void
+static gboolean
 window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
 {
   /* Handle fullscreen, in case something else takes us to/from fullscreen. */
   if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
     set_fullscreen_actions (event->new_window_state
 			    & GDK_WINDOW_STATE_FULLSCREEN);
+    
+  return FALSE;
 }
 
 
@@ -246,7 +249,7 @@ about_cb (GtkAction * action, gpointer data)
 			 _("A worm game for GNOME."), "authors", authors,
 			 "documenters", documenters, "translator-credits",
 			 _("translator-credits"), "logo-icon-name",
-			 "gnome-nibbles", "website",
+			 "gnome-gnibbles", "website",
 			 "http://www.gnome.org/projects/gnome-games/",
 			 "wrap-license", TRUE, NULL);
   g_free (license);
@@ -307,7 +310,7 @@ draw_board ()
 
 }
 
-static gint
+static gboolean
 window_configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
 {
   gnibbles_properties_set_height (event->height);
@@ -315,7 +318,7 @@ window_configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
   return FALSE;
 }
 
-static gint
+static gboolean
 configure_event_cb (GtkWidget * widget, GdkEventConfigure * event)
 {
   int tilesize, ts_x, ts_y;
@@ -985,9 +988,16 @@ load_properties ()
 			   gconf_key_change_cb, NULL, NULL, NULL);
 }
 
+
 static void
 render_logo (void)
 {
+  PangoContext *context;
+  PangoLayout *layout;
+  PangoFontDescription * pfd;
+  int size;
+  static int width, height;
+
   zero_board ();
 
   gdk_draw_pixbuf (GDK_DRAWABLE (buffer_pixmap),
@@ -997,17 +1007,54 @@ render_logo (void)
 		   BOARDHEIGHT * properties->tilesize, GDK_RGB_DITHER_NORMAL,
 		   0, 0);
 
+  context = gdk_pango_context_get ();
+  layout = pango_layout_new (context);
+  pfd = pango_context_get_font_description (context);
+  size = pango_font_description_get_size (pfd);
+  pango_font_description_set_size (pfd, 
+		(size * drawing_area->allocation.width) / 100);
+  pango_font_description_set_family (pfd, "Sans");
+  pango_font_description_set_weight(pfd, PANGO_WEIGHT_BOLD); 
+  pango_layout_set_font_description (layout, pfd);
+  pango_layout_set_text (layout, _("Nibbles"), -1);
+  pango_layout_get_pixel_size(layout, &width, &height);  
+
+  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->black_gc,  
+		   (drawing_area->allocation.width - width) * 0.5 + 3, 
+		   (drawing_area->allocation.height * 0.72) + 3, layout);
+  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->white_gc,  
+		   (drawing_area->allocation.width - width) * 0.5, 
+		   (drawing_area->allocation.height * 0.72), layout);
+
+  pango_font_description_set_size (pfd, 
+		(size * drawing_area->allocation.width) / 400);
+  pango_layout_set_font_description (layout, pfd);
+  /* Translators: This string will be included in the intro screen, so don't make sure it fits! */
+  pango_layout_set_text (layout, _("A worm game for GNOME."), -1);
+  pango_layout_get_pixel_size(layout, &width, &height);  
+
+  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->black_gc,
+		   (drawing_area->allocation.width - width) * 0.5 + 2, 
+                   (drawing_area->allocation.height * 0.94) + 2, layout);
+  gdk_draw_layout (GDK_DRAWABLE (buffer_pixmap), drawing_area->style->white_gc,
+		   (drawing_area->allocation.width - width) * 0.5,
+                   (drawing_area->allocation.height * 0.94), layout);
+
+
   gdk_draw_drawable (GDK_DRAWABLE (drawing_area->window),
 		     drawing_area->style->
-		     fg_gc[GTK_WIDGET_STATE (drawing_area)], buffer_pixmap, 0,
-		     0, 0, 0, BOARDWIDTH * properties->tilesize,
+		     fg_gc[GTK_WIDGET_STATE (drawing_area)], buffer_pixmap, 
+		     0, 0, 0, 0, BOARDWIDTH * properties->tilesize,
 		     BOARDHEIGHT * properties->tilesize);
+
+
 }
 
 int
 main (int argc, char **argv)
 {
   GnomeProgram *program;
+  GOptionContext *context;
 
   setgid_io_init ();
 
@@ -1015,11 +1062,16 @@ main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+  g_thread_init (NULL);
+  context = g_option_context_new (NULL);
+  g_option_context_add_group (context, games_sound_get_option_group ());
+
   program = gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
 				argc, argv,
+				GNOME_PARAM_GOPTION_CONTEXT, context,
 				GNOME_PARAM_POPT_TABLE, NULL,
 				GNOME_PARAM_APP_DATADIR, REAL_DATADIR, NULL);
-  gtk_window_set_default_icon_name ("gnome-nibbles");
+  gtk_window_set_default_icon_name ("gnome-gnibbles");
   srand (time (NULL));
 
   highscores = games_scores_new (&scoredesc);
